library(dplyr)
library(shar)
library(spatstat.core)
library(testthat)

test_check("shar")
